@@ -25,6 +25,14 @@ app.config.from_object(__name__)
 socket_map = dict()
 
 
+def make_rsp(rsp):
+    format_tpl = u'\n/' + u'-' * 80 + u'\n%s\n' + u'-' * 80 + u'/\n'
+
+    if isinstance(rsp, dict):
+        rsp = json.dumps(rsp, indent=4, ensure_ascii=False)
+
+    return format_tpl % rsp
+
 @app.route('/call/<remote_endpoint>')
 def remote_call(remote_endpoint):
     """
@@ -39,30 +47,35 @@ def remote_call(remote_endpoint):
     try:
         sock.connect((app.config['GOURD_SERVER_HOST'], app.config['GOURD_SERVER_PORT']))
     except Exception, e:
-        return 'connect fail. e: %s' % e
+        return make_rsp('connect to gourd server fail. e: %s' % e)
 
     try:
         sock.send(json.dumps(send_dict)+current_app.config['TERMINATOR'])
     except Exception, e:
-        return 'send fail. e: %s' % e
+        return make_rsp('send to gourd server fail. e: %s' % e)
 
     socket_map[unique_id] = sock
 
     def generate():
-        yield '<pre>unique_id: %s</pre>' % unique_id
+        yield make_rsp('unique_id: %s' % unique_id)
 
         while True:
             f = sock.makefile('rw')
             recv_data = f.readline()
             if not recv_data:
                 current_app.logger.debug('gourd server closed socket')
-                yield '<pre>gourd server closed socket</pre>'
+                yield make_rsp('gourd server closed socket')
                 if unique_id in socket_map:
                     socket_map.pop(unique_id).close()
                 break
             else:
                 current_app.logger.debug('recv_data: %s', recv_data)
-                yield '<pre>%s</pre>' % recv_data
+                try:
+                    jdata = json.loads(recv_data)
+                    yield make_rsp(jdata)
+                except Exception, e:
+                    current_app.logger.error('json.loads(recv_data) fail: %s', e)
+                    yield make_rsp(recv_data)
 
     return Response(stream_with_context(generate()))
 
@@ -72,16 +85,16 @@ def close_conn(unique_id):
     sock = socket_map.pop(unique_id, None)
 
     if not sock:
-        return 'sock not in socket_map'
+        return make_rsp('sock not in socket_map')
     else:
         sock.close()
-        return 'sock closed'
+        return make_rsp('sock succ closed')
 
 
 @app.route('/stat')
 def stat():
     stat_dict = dict([(k, v.fileno()) for k, v in socket_map.items()])
-    return '<pre>%s</pre>' % json.dumps(stat_dict, indent=4)
+    return make_rsp(stat_dict)
 
 
 def build_parser():
