@@ -192,19 +192,21 @@ class GourdTcp(asyncore.dispatcher, CallBackMgr):
     backlog = None
     terminator = None
     logger = None
+    request_handler_class = None
 
-    def __init__(self, name=None, terminator=None, backlog=None):
+    def __init__(self, log_name=None, terminator=None, backlog=None, request_handler_class=None):
         # 把map变成私有的
         asyncore.dispatcher.__init__(self, map=dict())
         CallBackMgr.__init__(self)
-        self.logger = logging.getLogger(name or constants.NAME)
+        self.logger = logging.getLogger(log_name or constants.LOG_NAME)
         self.terminator = terminator or constants.TERMINATOR
         self.backlog = backlog or constants.BACKLOG
+        self.request_handler_class = request_handler_class or TcpRequestHandler
 
     def handle_accept(self):
         sock, address = self.accept()
         self.logger.debug('accept. socket:%s, address:%s', sock, address)
-        TcpRequestHandler(self, address, self.terminator, sock, self._map)
+        self.request_handler_class(self, address, self.terminator, sock, self._map)
 
     def run(self, host, port):
         self.create_socket(socket.AF_INET, socket.SOCK_STREAM)
@@ -290,24 +292,28 @@ class TcpRequestHandler(asynchat.async_chat):
 
 
 class GourdUdp(asyncore.dispatcher, CallBackMgr):
-    _address = None
-    _raw_data = None
-    _json_data = None
-
     logger = None
+    request_handler_class = None
 
-    def __init__(self, name=None):
+    def __init__(self, log_name=None, request_handler_class=None):
         # 把map变成私有的
         asyncore.dispatcher.__init__(self, map=dict())
         CallBackMgr.__init__(self)
-        self.logger = logging.getLogger(name or constants.NAME)
+        self.logger = logging.getLogger(log_name or constants.LOG_NAME)
+        self.request_handler_class = request_handler_class or UdpRequestHandler
 
     @catch_exc
     def handle_read(self):
         raw_data, address = self.socket.recvfrom(constants.PACKAGE_SIZE)
-        request = UdpRequestHandler(self, address, raw_data)
+        request = self.request_handler_class(self, address, raw_data)
         request.process()
 
+    def writable(self):
+        """
+        因为发送数据是直接sendto了，所以可以减少很多写事件循环
+        """
+        return False
+
     def run(self, host, port):
         self.create_socket(socket.AF_INET, socket.SOCK_DGRAM)
         self.bind((host, port))
